Package: promor
Type: Package
Title: Proteomics Data Analysis and Modeling Tools
Version: 0.2.3
Authors@R: person(given = "Chathurani",
           family = "Ranathunge",
           role = c("aut", "cre", "cph"),
           email = "caranathunge86@gmail.com",
           comment = c(ORCID = "0000-0003-1901-2119"))
Description: A comprehensive, user-friendly package for label-free proteomics data analysis and machine learning-based modeling. Data generated from 'MaxQuant' can be easily used to conduct differential expression analysis, build predictive models with top protein candidates, and assess model performance. promor includes a suite of tools for quality control, visualization, missing data imputation (Lazar et. al. (2016) <doi:10.1021/acs.jproteome.5b00981>), differential expression analysis (Ritchie et. al. (2015) <doi:10.1093/nar/gkv007>), and machine learning-based modeling (Kuhn (2008) <doi:10.18637/jss.v028.i05>).
License: LGPL (>= 2.1)
Encoding: UTF-8
Language: en-US
RoxygenNote: 7.3.3
VignetteBuilder: knitr
Suggests: covr, knitr, rmarkdown, testthat (>= 3.0.0)
Depends: R (>= 3.5.0)
URL: https://github.com/caranathunge/promor,
        https://caranathunge.github.io/promor/
biocViews:
Imports: reshape2, ggplot2, ggrepel, gridExtra, limma, statmod,
        pcaMethods, VIM, missForest, caret, kernlab, xgboost,
        naivebayes, viridis, pROC
LazyData: true
Config/testthat/edition: 3
BugReports: https://github.com/caranathunge/promor/issues
NeedsCompilation: no
Packaged: 2026-05-07 07:32:06 UTC; caran
Author: Chathurani Ranathunge [aut, cre, cph] (ORCID:
    <https://orcid.org/0000-0003-1901-2119>)
Maintainer: Chathurani Ranathunge <caranathunge86@gmail.com>
Repository: CRAN
Date/Publication: 2026-05-07 08:00:09 UTC
Built: R 4.6.0; ; 2026-05-07 11:44:05 UTC; unix
