# Generated by roxygen2: do not edit by hand

export(aver_techreps)
export(corr_plot)
export(create_df)
export(feature_plot)
export(filterbygroup_na)
export(find_dep)
export(heatmap_de)
export(heatmap_na)
export(impute_na)
export(impute_plot)
export(norm_plot)
export(normalize_data)
export(onegroup_only)
export(performance_plot)
export(pre_process)
export(rem_feature)
export(rem_sample)
export(roc_plot)
export(split_data)
export(test_models)
export(train_models)
export(varimp_plot)
export(volcano_plot)
import(caret)
import(ggplot2)
import(ggrepel)
import(gridExtra)
import(limma)
import(naivebayes)
import(statmod)
import(stats)
import(viridis)
import(xgboost)
importFrom(VIM,kNN)
importFrom(kernlab,sigest)
importFrom(missForest,missForest)
importFrom(pROC,roc)
importFrom(pcaMethods,completeObs)
importFrom(pcaMethods,pca)
importFrom(reshape2,melt)
importFrom(stats,aggregate)
importFrom(stats,cor)
importFrom(stats,median)
importFrom(stats,model.matrix)
importFrom(stats,quantile)
importFrom(stats,reorder)
importFrom(stats,rnorm)
importFrom(stats,sd)
importFrom(utils,read.csv)
importFrom(utils,write.table)
importFrom(viridis,scale_color_viridis)
